/*
 * IntuitionGraphs.qml  -  Parent overview to build multiple IntuitionBuildGraphs for display
 *
 * Copyright © 2023,2024 IntuitionSailing.com.  All rights reserved.
 * Contact: IntiutionSailing http://www.intuitionsailing.com don@intuitionsailing.com
 *
*/

import QtQuick 1.1
import "utils.js" as Utils

OverviewPage {

  id: root
  title: qsTr( (systemName.valid && systemName.length > 0 ? systemName.value + "'s " : "" ) + "Graphs")

  // Default values
  property string _myPrefix: "com.victronenergy.settings/Settings/Intuition"
  property int _numberGraphs:        10
  property int _defaultHeight :      84
  property int _defaultWidth:        160
  property real _defaultZoom :       1.25
  property int _zoom:                -1

  property VBusItem systemName: VBusItem {bind: Utils.path(bindPrefix, "/Settings/SystemSetup/SystemName")}

  // Height and width are defined here, to handle zoom
  property list<VBusItem> heightListItem : [
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/0/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/1/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/2/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/3/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/4/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/5/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/6/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/7/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/8/Height")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/9/Height")}
  ]

  property list<VBusItem> widthListItem : [
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/0/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/1/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/2/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/3/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/4/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/5/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/6/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/7/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/8/Width")},
    VBusItem {bind: Utils.path(_myPrefix,"/Graphs/9/Width")}
  ]
  
  // Begin layout
  IntuitionPageHeader {
    id: header
    height: 16
    width: parent.width
    caption: "Graphs"
  }

  transform: Scale { id: tform }      // Mouse click zoom on selected chart

  // Shift zoom X position using graph's X position
  function zoomX(x) {
    return x/2
  }

  // Shift zoom Y position using graph's Y position
  function zoomY(y) {
    if(y < 80) return header.height
    return 80 + header.height
  }

  // Added Flow to allow different heights and widths
  Flow {
    anchors.fill: parent
    anchors.topMargin: header.height

    flow: Flow.TopToBottom

    Repeater {
      id: g
      model: _numberGraphs 

      IntuitionBuildGraph {
        graphId:          index
        height:           (heightListItem[index].valid && heightListItem[index].value != "" ? 
                             parseInt(heightListItem[index].value) : _defaultHeight )
        width:            (widthListItem[index].valid && widthListItem[index].value != "" ? 
                             parseInt(widthListItem[index].value) : _defaultWidth )
        MouseArea {
          anchors.fill: parent
          onPressed: {
            root._zoom = (root._zoom == -1 ? 1 : -1)

            tform.xScale = tform.xScale + root._zoom * _defaultZoom
            tform.yScale = tform.yScale + root._zoom * _defaultZoom

            tform.origin.x = parent.x + zoomX(parent.x)
            tform.origin.y = parent.y + zoomY(parent.y)

          }  // onPressed
        }  // MouseArea
      }  // IntuitionBuildGraph
    } // Repeater
  }  // Flow
}  // OverviewPage